Class: OmniAuth::Strategies::RocketChat
- Inherits:
-
OAuth2
- Object
- OAuth2
- OmniAuth::Strategies::RocketChat
- Defined in:
- lib/omniauth/strategies/rocketchat.rb
Overview
Authorization strategy for Rocket Chat using OAuth2.
Allows your custom application to integrate with Rocket Chat through their "Third-party login" feature. See: https://docs.rocket.chat/docs/third-party-login for more information.
To use it, you'll need to register your application with your Rocket Chat instance and get a client ID and secret on the admin page, e.g. https://example.com/admin/third-party-login
Constant Summary collapse
- PROFILE_INFO_ENDPOINT =
Returns profile information about the authenticated user.
"/api/v1/me"- DEFAULT_AUTHORIZE_URL =
"/oauth/authorize"- DEFAULT_TOKEN_URL =
"/oauth/token"
Instance Method Summary collapse
Instance Method Details
#callback_url ⇒ Object
103 104 105 |
# File 'lib/omniauth/strategies/rocketchat.rb', line 103 def callback_url full_host + callback_path end |